<?php

namespace App\Http\Controllers;

use App\Models\Code;
use App\Models\Exam;
use App\Models\Question;
use App\Models\Quiz;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Symfony\Component\Console\Input\Input;

class QuizController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function start()
    {
        return view('frontend.start');
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function new(Request $request)
    {
        if (Code::where('code', '=', $request->code)->exists() && Code::where('code', '=', $request->code)->first()->status == 'available') {
            // update code status
            $code = Code::where('code', $request->code)->first();
            $code['status'] = 'expired';
            $code->save();

            $questions = Question::all();
            return view('frontend.home', compact('questions'));
        }else {
            session()->flash('error', 'لا يمكنك إنشاء الأختبار .. تأكد من صحة الكود الخاص بك');
            return view('frontend.start');
        }
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {

            $questions = Question::all();
            return view('frontend.home', compact('questions'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $exam = new Exam();
        $exam->user_id = Auth::id();
        $exam->save();

        $questions = Question::all()->count();

        for($x = 0; $x<$questions; $x++) {
          $quiz = new Quiz();
          $quiz->exam_id = $exam->id;
          $quiz->question_id = request('question_id_'. $x+1);
          $quiz->category = request('category_'. $x+1);
          $quiz->answer = request('q_'. $x+1);
          $quiz->save();
        }

        $a_count = Quiz::where([['exam_id', $exam->id], ['category', 'A'], ['answer', 'نعم']])->count();
        $b_count = Quiz::where([['exam_id', $exam->id], ['category', 'B'], ['answer', 'نعم']])->count();
        $c_count = Quiz::where([['exam_id', $exam->id], ['category', 'C'], ['answer', 'نعم']])->count();
        $d_count = Quiz::where([['exam_id', $exam->id], ['category', 'D'], ['answer', 'نعم']])->count();

        $u_exam = Exam::find($exam->id);
        $u_exam->update([
            'a_percentage' => (int)$a_count / 14 * 100,
            'b_percentage' => (int)$b_count / 14 * 100,
            'c_percentage' => (int)$c_count / 14 * 100,
            'd_percentage' => (int)$d_count / 14 * 100,

            'done' => true
        ]);
        $u_exam->save();

        session()->flash('success', 'تم الانتهاء من الإختبار بنجاح');

        $exams = Exam::where('user_id', Auth::id())->orderBy('created_at', 'DESC')->get();
        return view('frontend.exams.index', compact('exams'));
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Quiz  $quiz
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $exam = Exam::find($id);
        return view('frontend.exams.show', compact('exam'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Quiz  $quiz
     * @return \Illuminate\Http\Response
     */
    public function edit(Quiz $quiz)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Quiz  $quiz
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Quiz $quiz)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Quiz  $quiz
     * @return \Illuminate\Http\Response
     */
    public function destroy(Quiz $quiz)
    {
        //
    }
}
